@@ -1,8 +1,6 @@
 package VCI::VCS::Hg::Directory;
 use Moose;
 
-use VCI::VCS::Hg::File;
-
 extends 'VCI::Abstract::Directory';
 with 'VCI::VCS::Hg::Committable';
 
@@ -18,21 +16,21 @@ sub _build_contents {
     my @contents;
     foreach my $dir_line (@dir_lines) {
         $dir_line =~ /^\S+ (.*)$/;
-        push(@contents, VCI::VCS::Hg::Directory->new(path => [$self->path, $1],
-                                                     project => $self->project,
-                                                     revision => $self->revision,
-                                                     parent => $self));
+        push(@contents, $self->directory_class->new(path => [$self->path, $1],
+                                                    project => $self->project,
+                                                    revision => $self->revision,
+                                                    parent => $self));
     }
     foreach my $file_line (@file_lines) {
         $file_line =~ /^(\S+) (\d+) (.*)$/;
         my ($properties, $size, $name) = ($1, $2, $3);
         my $executable = 0;
         $executable = 1 if $properties =~ /x/;
-        push(@contents, VCI::VCS::Hg::File->new(path => [$self->path, $name],
-                                                is_executable => $executable,
-                                                content_size => $size,
-                                                project => $self->project,
-                                                parent => $self));
+        push(@contents, $self->file_class->new(path => [$self->path, $name],
+                                               is_executable => $executable,
+                                               content_size => $size,
+                                               project => $self->project,
+                                               parent => $self));
     }
     return \@contents;
 }
